@@ -11,7 +11,7 @@ this header file lives".
 
 # created 2000/05/29, Greg Ward
 
-__revision__ = "$Id: config.py,v 1.10 2001/12/06 20:57:12 fdrake Exp $"
+__revision__ = "$Id: config.py,v 1.10.6.1 2002/09/24 11:22:28 mwh Exp $"
 
 import sys, os, string, re
 from types import *
@@ -348,7 +348,8 @@ class config (Command):
         exists and can be found by the preprocessor; return true if so,
         false otherwise.
         """
-        return self.try_cpp(headers=[header], include_dirs=include_dirs)
+        return self.try_cpp(body="/* No body */", headers=[header],
+                            include_dirs=include_dirs)
 
 
 # class config
